@@ -3,9 +3,9 @@
 package App::ModuleUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-03'; # DATE
+our $DATE = '2022-08-12'; # DATE
 our $DIST = 'App-PMUtils'; # DIST
-our $VERSION = '0.738'; # VERSION
+our $VERSION = '0.739'; # VERSION
 
 1;
 # ABSTRACT: Alias for App::PMUtils
@@ -22,7 +22,7 @@ App::ModuleUtils - Alias for App::PMUtils
 
 =head1 VERSION
 
-This document describes version 0.738 of App::ModuleUtils (from Perl distribution App-PMUtils), released on 2021-12-03.
+This document describes version 0.739 of App::ModuleUtils (from Perl distribution App-PMUtils), released on 2022-08-12.
 
 =head1 HOMEPAGE
 
@@ -53,13 +53,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
