@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-03'; # DATE
+our $DATE = '2022-08-12'; # DATE
 our $DIST = 'App-PMUtils'; # DIST
-our $VERSION = '0.738'; # VERSION
+our $VERSION = '0.739'; # VERSION
 
 our %SPEC;
 
@@ -19,7 +19,6 @@ our $arg_module_multiple = {
         min_len=>1,
         'x.perl.default_value_rules' => ["Perl::these_mods"],
     }],
-    'x.perinci.cmdline.default_from_schema' => 1,
     #req    => 1,
     pos    => 0,
     slurpy => 1,
@@ -34,7 +33,6 @@ our $arg_module_single = {
     schema => ['perl::modname*', {
         'x.perl.default_value_rules' => ["Perl::this_mod"],
     }],
-    'x.perinci.cmdline.default_from_schema' => 1,
     #req    => 1,
     pos    => 0,
     completion => sub {
@@ -313,7 +311,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.738 of App::PMUtils (from Perl distribution App-PMUtils), released on 2021-12-03.
+This document describes version 0.739 of App::PMUtils (from Perl distribution App-PMUtils), released on 2022-08-12.
 
 =head1 SYNOPSIS
 
@@ -713,13 +711,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
